@@ -35,11 +35,13 @@ import pystac.extensions.label
 import pystac.extensions.projection
 import pystac.extensions.view
 import pystac.extensions.single_file_stac
+import pystac.extensions.timestamps
 
 STAC_EXTENSIONS = extensions.base.RegisteredSTACExtensions([
     extensions.eo.EO_EXTENSION_DEFINITION, extensions.label.LABEL_EXTENSION_DEFINITION,
     extensions.projection.PROJECTION_EXTENSION_DEFINITION,
-    extensions.view.VIEW_EXTENSION_DEFINITION, extensions.single_file_stac.SFS_EXTENSION_DEFINITION
+    extensions.view.VIEW_EXTENSION_DEFINITION, extensions.single_file_stac.SFS_EXTENSION_DEFINITION,
+    extensions.timestamps.TIMESTAMPS_EXTENSION_DEFINITION
 ])
 
 
