@@ -1,35 +1,34 @@
 import unittest
 from tempfile import TemporaryDirectory
 
-from pystac import (STAC_IO, STACObject, CatalogType, LinkType)
+from pystac import (STAC_IO, STACObject, Collection, CatalogType, LinkType)
+from pystac.serialization import (STACObjectType)
 from pystac.utils import make_absolute_href
+from pystac.validation import validate_dict
 
-from tests.utils import (TestCases, SchemaValidator)
+from tests.utils import TestCases
 
 
 class STACWritingTest(unittest.TestCase):
     """Tests writing STACs, using JSON Schema validation,
     and ensure that links are correctly set to relative or absolute.
     """
-    def setUp(self):
-        self.schema_validator = SchemaValidator()
-
     def validate_catalog(self, catalog):
-        self.schema_validator.validate_object(catalog)
+        catalog.validate()
         validated_count = 1
 
         for child in catalog.get_children():
             validated_count += self.validate_catalog(child)
 
         for item in catalog.get_items():
-            self.schema_validator.validate_object(item)
+            item.validate()
             validated_count += 1
 
         return validated_count
 
     def validate_file(self, path, object_type):
         d = STAC_IO.read_json(path)
-        return self.schema_validator.validate_dict(d, object_type)
+        return validate_dict(d, object_type)
 
     def validate_link_types(self, root_href, catalog_type):
         def validate_item_link_type(href, link_type, should_include_self):
@@ -39,7 +38,7 @@ class STACWritingTest(unittest.TestCase):
                 if not link.rel == 'self':
                     self.assertEqual(link.link_type, link_type)
 
-            rels = set([l['rel'] for l in item_dict['links']])
+            rels = set([link['rel'] for link in item_dict['links']])
             self.assertEqual('self' in rels, should_include_self)
 
         def validate_catalog_link_type(href, link_type, should_include_self):
@@ -49,7 +48,7 @@ class STACWritingTest(unittest.TestCase):
                 if not link.rel == 'self':
                     self.assertEqual(link.link_type, link_type)
 
-            rels = set([l['rel'] for l in cat_dict['links']])
+            rels = set([link['rel'] for link in cat_dict['links']])
             self.assertEqual('self' in rels, should_include_self)
 
             for child_link in cat.get_child_links():
@@ -83,10 +82,14 @@ class STACWritingTest(unittest.TestCase):
             self.validate_link_types(root_href, catalog_type)
 
             for parent, children, items in catalog.walk():
-                self.validate_file(parent.get_self_href(), type(parent))
+                if issubclass(type(parent), Collection):
+                    stac_object_type = STACObjectType.COLLECTION
+                else:
+                    stac_object_type = STACObjectType.CATALOG
+                self.validate_file(parent.get_self_href(), stac_object_type)
 
                 for item in items:
-                    self.validate_file(item.get_self_href(), type(item))
+                    self.validate_file(item.get_self_href(), STACObjectType.ITEM)
 
     def test_testcases(self):
         for catalog in TestCases.all_test_catalogs():
